'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var loom = require('@shopify/loom');
var loomPluginBabel = require('@shopify/loom-plugin-babel');
var loomPluginTypescript = require('@shopify/loom-plugin-typescript');
var loomPluginJest = require('@shopify/loom-plugin-jest');
var loomPluginRollup = require('@shopify/loom-plugin-rollup');
var pluginRollupConfig = require('./plugin-rollup-config.js');
var pluginJestConfig = require('./plugin-jest-config.js');
var pluginWriteBinaries = require('./plugin-write-binaries.js');
var pluginWriteEntrypoints = require('./plugin-write-entrypoints.js');

function buildLibrary({
  targets,
  commonjs = false,
  esmodules = false,
  esnext = false,
  binaries = true,
  rootEntrypoints = true,
  jestTestEnvironment = 'node'
}) {
  return loom.createComposedProjectPlugin('BuildLibrary', [loomPluginBabel.babel({
    config: {
      presets: [[require.resolve('@shopify/babel-preset'), {
        typescript: true,
        react: true
      }]],
      // Disable loading content from babel.config.js
      configFile: false
    }
  }), loomPluginRollup.rollupHooks(), loomPluginRollup.rollupBuild(), pluginRollupConfig.rollupConfig({
    targets,
    commonjs,
    esmodules,
    esnext
  }), pluginJestConfig.jestConfig({
    jestTestEnvironment
  }), binaries && pluginWriteBinaries.writeBinaries(), rootEntrypoints && pluginWriteEntrypoints.writeEntrypoints({
    commonjs,
    esmodules,
    esnext
  })]);
}
function buildLibraryWorkspace() {
  return loom.createComposedWorkspacePlugin('BuildLibraryWorkspace', [loomPluginTypescript.typescript(), loomPluginJest.jest()]);
}

exports.buildLibrary = buildLibrary;
exports.buildLibraryWorkspace = buildLibraryWorkspace;
