'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var path = require('path');
var loom = require('@shopify/loom');
var findCommonAncestorPath = require('common-ancestor-path');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var findCommonAncestorPath__default = /*#__PURE__*/_interopDefaultLegacy(findCommonAncestorPath);

function writeBinaries() {
  return loom.createProjectBuildPlugin('BuildLibrary.Binaries', ({
    hooks,
    project,
    api
  }) => {
    hooks.steps.hook(steps => project.binaries.length > 0 ? [...steps, createWriteBinariesStep({
      project,
      api
    })] : steps);
  });
}

function createWriteBinariesStep({
  project,
  api
}) {
  return api.createStep({
    id: 'BuildLibrary.Binaries',
    label: `Write binaries`
  }, async step => {
    const commonEntryRoot = findCommonAncestorPath__default["default"](...(await Promise.all([...project.entries, ...project.binaries].map(async ({
      root
    }) => path.dirname(project.fs.resolvePath(root)))))); // This is present as a typeguard that should never trigger as
    // findCommonAncestorPath will only return null if you're on windows and you
    // feed it files that are on different drives - which should never occur if
    // you're building a project that is contained within a single folder

    if (commonEntryRoot === null) {
      throw new Error('Could not find a common ancestor folder for all your entrypoints');
    }

    await Promise.all(project.binaries.map(async ({
      name,
      root,
      aliases = []
    }) => {
      const binaryPath = project.fs.resolvePath(root);
      const sourceFileRelativeToCommonRoot = path.relative(commonEntryRoot, binaryPath);
      const pathToBuiltBinary = `./${path.relative(project.fs.resolvePath('bin'), path.join(project.fs.resolvePath('build/cjs'), sourceFileRelativeToCommonRoot.replace(/\.[^.]+$/, '.js')))}`;

      for (const binaryName of [name, ...aliases]) {
        const binaryFile = project.fs.resolvePath('bin', binaryName);
        await project.fs.write(binaryFile, `#!/usr/bin/env node\nrequire(${JSON.stringify(pathToBuiltBinary)})`);
        await step.exec('chmod', ['+x', binaryFile]);
      }
    }));
  });
}

exports.writeBinaries = writeBinaries;
